#include <stdio.h>
#include <errno.h>
#include <string.h>
#include <unistd.h>
#include <stdlib.h>

#include "crypto.h"

extern int errno;

const char * VALID_NONCE_CHARS = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789./";

/**
 * Puts a valid two-character nonce into
 * the buffer passed as the argument. Uses
 * /dev/urandom as a source of randomness.
 * The valid salt characters for crypt are
 * define by VALID_NONCE_CHARS in
 * crypto.h.
 *
 * Returns 0 on success; -1 on error. errno
 * is set on error.
 */
int create_nonce(char * noncebuf) {
  char randbuf[2];
  int rval = 0, i;
  unsigned int index;
  FILE * rand;
  
  //open the /dev/urandom device to
  //get some random bytes
  rand = fopen("/dev/urandom","r");
  if (rand == NULL) return -1;
  
  //get two random bytes
  rval = fread(randbuf,1,2,rand);
  if (rval < 2) {
    errno = EAGAIN;
  }
  
  rval = fclose(rand);
  if (rval != 0) {
    //we don't fail out here
    perror("Warning! Couldn't fclose /dev/urandom");
  }  
  
  
  //put two nonce chars in the buffer
  for (i = 0; i < 2; i++) {
    index = (unsigned int)randbuf[i] % strlen(VALID_NONCE_CHARS);
    noncebuf[i] = VALID_NONCE_CHARS[index];
  }

  return 0;
}

void encrypt_pass(char * newpass, char * oldpass, int len) {
  int oldlen, newi, oldi = 0;
  oldlen = strlen(oldpass);

  for(newi = 0; newi < len; newi++) {
    newpass[newi] = (char)(newpass[newi] ^ oldpass[oldi]);
    oldi = (oldi + 1) % oldlen;
  }
}

char * getpassword(char * prompt) {
#ifdef _TURNIN_SUN
  return getpassphrase(prompt);
#endif
 return getpass(prompt);
}
