/*
 * Copyright (c) 1997,2000 University of Michigan, Ann Arbor.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms are permitted
 * provided that the above copyright notice and this paragraph are
 * duplicated in all such forms and that any documentation,
 * advertising materials, and other materials related to such
 * distribution and use acknowledge that the software was developed
 * by the University of Michigan, Ann Arbor. The name of the University 
 * may not be used to endorse or promote products derived from this 
 * software without specific prior written permission.
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * Author: Sugih Jamin (jamin@eecs.umich.edu)
 *         Eric Cronin (ecronin@eecs.umich.edu)
 *         Wenjie Wang (wenjiew@eecs.umich.edu)
 *         Matt England (moenglan@eecs.umich.edu)
 *
*/
#ifndef __turnin_h__
#define __turnin_h__

#include <sys/types.h>
#include <sys/errno.h>
#include <unistd.h>

#define CRYPT_LEN 13

#define TIN_VERS  3
#define TIN_PUT   1
#define TIN_LST   2
#define TIN_SETPASS 3
#define TIN_ALEN  4           /* Length of the null terminated assignment name */
#define TIN_ULEN  9           /* Max length of the null terminated student's uniqname */
#define TIN_FLEN  80          /* Max length of the null terminated filename */
#define TIN_MLEN  512         /* Buffer for messages. */
#define TIN_DLEN  16384       /* Buffer to hold file data. */
#define TIN_SRVR  "localhost" /* Default to localhost for testing purposes. */
#define TIN_PORT  4891        /* The turnin program's "well-known" port. */
#define TIN_CHALLENGE_LEN 11

#define TIND_CHALLENGE_LEN 15
#define TIND_MAXTRIES 10
#define TIND_SLEEPUSEC 500000
#define TIND_PASSDIR "passwds" /* The daemon's password file directory. Must be relative. */

typedef struct _tin_head tih_t;
typedef struct _tif_head tif_t;

struct _tin_head {
  unsigned short tih_vers;          /* version number */
  unsigned short tih_op;            /* operation, one of TIN_PUT or TIN_LST */
  char tih_asgn[TIN_ALEN];   /* Assignment name: a null terminated string of
                                exactly TIN_ALEN-1 characters. */
  unsigned short tih_nfiles;        /* Number of files being turned in. */
};

struct _tif_head {
  char tif_fname[TIN_FLEN];  /* File name: a null terminated string of
                                at most TIN_FLEN-1 characters. If strlen
                                is shorter then TIN_FLEN-1, rest of field
                                is garbage. */
  unsigned long tif_fsize;          /* File size. */
};

/* on error, dump core to help debugging. */
#define tin_check_err(err, errmsg) { if (err) { perror(errmsg);/* exit(errno) */abort(); } }

#endif /*__turin_h__*/

